// Text Browser as a dialog
unit DlgBrowserDialog;

interface

uses SysUtils, Classes, QGraphics, QForms, QButtons, QExtCtrls, QControls,
  QStdCtrls, QComCtrls, IdBaseComponent, IdComponent, IdTCPConnection,
  IdTCPClient, IdHTTP, IdUri;


type
  // type to create a browser in dialog form
  TDlgBrowser = class(TForm)
    pnlButton: TPanel;
    btnClose: TButton;
    txbBrowser: TTextBrowser;
    httpClient: TIdHTTP;
    procedure txbBrowserHighlightText(Sender: TObject;
      const HighlightedText: WideString);
    procedure txbBrowserClick(Sender: TObject);
    procedure btnCloseClick(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    // Private declarations 
    FLastUrl: String;
    
    procedure GoToUrl(NewUrl: String);

  public
    // Public declarations
    // the new request (e.g.: 'http: //...' or '/...' or '...' (always with the http protocol) 
    NewRequest: String;
    text: String;
  end;

var
  DlgBrowser: TDlgBrowser;

implementation

{$R *.xfm}

procedure TDlgBrowser.txbBrowserHighlightText(Sender: TObject;
  const HighlightedText: WideString);
begin
  NewRequest := HighlightedText;
end;

procedure TDlgBrowser.txbBrowserClick(Sender: TObject);
var
  Uri: TIdUri;
begin
  if NewRequest <> '' then
  begin
   Uri := TIdUri.Create(FLastUrl);
   if Pos('http:', NewRequest) > 0 then
     GotoUrl(NewRequest)
   else if NewRequest[1] = '/' then
     GotoUrl('http://' + Uri.Host + NewRequest)
   else
     GotoUrl('http://' + Uri.Host + Uri.Path + NewRequest);
  end;
end;

procedure TDlgBrowser.GoToUrl(NewUrl: String);
begin
  Screen.Cursor := crHourGlass;
  try
    txbBrowser.Text := httpClient.Get(NewUrl);
    text := txbBrowser.Text;

    if AnsiPos('html', LowerCase(httpClient.Response.ContentType)) <> 0 then
      txbBrowser.TextFormat := tfText
    else
      txbBrowser.TextFormat := tfPlainText;

    FLastUrl := NewUrl;
    NewRequest := '';
  finally
    Screen.Cursor := crDefault;
  end;
end;

procedure TDlgBrowser.btnCloseClick(Sender: TObject);
begin
  ModalResult := mrOK;
end;

procedure TDlgBrowser.FormActivate(Sender: TObject);
begin
  txbBrowser.UseDefaultFactory := true;
end;

procedure TDlgBrowser.FormShow(Sender: TObject);
begin
  FLastUrl := NewRequest;
  txbBrowser.Text := text;
end;

end.
